@@ -12,7 +12,7 @@ BEGIN {
   $Dist::Zilla::PluginBundle::RSRCHBOY::AUTHORITY = 'cpan:RSRCHBOY';
 }
 BEGIN {
-  $Dist::Zilla::PluginBundle::RSRCHBOY::VERSION = '0.003';
+  $Dist::Zilla::PluginBundle::RSRCHBOY::VERSION = '0.004';
 }
 
 # ABSTRACT: Zilla your Dists like RSRCHBOY!
@@ -23,6 +23,43 @@ use namespace::autoclean;
 use Dist::Zilla;
 with 'Dist::Zilla::Role::PluginBundle::Easy';
 
+use Dist::Zilla::PluginBundle::Git;
+
+use Dist::Zilla::Plugin::Authority;
+use Dist::Zilla::Plugin::CheckPrereqsIndexed;
+use Dist::Zilla::Plugin::CompileTests;
+use Dist::Zilla::Plugin::ConfirmRelease;
+use Dist::Zilla::Plugin::ConsistentVersionTest;
+use Dist::Zilla::Plugin::EOLTests;
+use Dist::Zilla::Plugin::ExtraTests;
+use Dist::Zilla::Plugin::Git::NextVersion;
+use Dist::Zilla::Plugin::GitHub::Meta;
+use Dist::Zilla::Plugin::GitHub::Update;
+use Dist::Zilla::Plugin::HasVersionTests;
+use Dist::Zilla::Plugin::MetaConfig;
+use Dist::Zilla::Plugin::MetaJSON;
+use Dist::Zilla::Plugin::MetaYAML;
+use Dist::Zilla::Plugin::MinimumPerl;
+use Dist::Zilla::Plugin::NoSmartCommentsTests;
+use Dist::Zilla::Plugin::NoTabsTests;
+use Dist::Zilla::Plugin::PodWeaver;
+use Dist::Zilla::Plugin::PodCoverageTests;
+use Dist::Zilla::Plugin::PodSyntaxTests;
+use Dist::Zilla::Plugin::PortabilityTests;
+use Dist::Zilla::Plugin::Prepender;
+use Dist::Zilla::Plugin::ReadmeFromPod;
+use Dist::Zilla::Plugin::ReportVersions;
+use Dist::Zilla::Plugin::TaskWeaver;
+use Dist::Zilla::Plugin::TestRelease;
+use Dist::Zilla::Plugin::UploadToCPAN;
+
+has is_task => (
+    is      => 'ro',
+    isa     => 'Bool',
+    lazy    => 1,
+    default => sub { shift->payload->{task} },
+);
+
 sub configure {
     my $self = shift @_;
 
@@ -39,7 +76,6 @@ sub configure {
         { version_regexp => '^(\d.\d+)$' },
     ]);
 
-
     $self->add_plugins(
         qw{
             GatherDir
@@ -51,7 +87,6 @@ sub configure {
             InstallGuide
             Manifest
             PkgVersion
-            PodWeaver
             ReadmeFromPod
             AutoPrereqs
 
@@ -84,6 +119,8 @@ sub configure {
             GitHub::Update
         },
 
+        ($self->is_task ? 'TaskWeaver' : 'PodWeaver'),
+
         [ ReadmeAnyFromPod  => ReadmePodInRoot => {
             type     => 'pod',
             filename => 'README.pod',
@@ -116,7 +153,7 @@ Dist::Zilla::PluginBundle::RSRCHBOY - Zilla your Dists like RSRCHBOY!
 
 =head1 VERSION
 
-version 0.003
+version 0.004
 
 =head1 DESCRIPTION
 
